@@ -1,14 +1,12 @@
 import os
 from enum import Enum
 
-from distributed_logger.loggers.logger import Logger, KafkaLogger, SimpleLogger
-from distributed_logger.models.config import Config, KafkaConfig, SimpleConfig
+from distributed_logger.loggers.logger import Logger, KafkaLogger
+from distributed_logger.models.config import  KafkaConfig
 
 
 class EnvType(Enum):
     KAFKA = "KAFKA"
-    SIMPLE = "SIMPLE"
-
 
 class LoggerFactory:
     """
@@ -16,14 +14,14 @@ class LoggerFactory:
     - Selects environment based on the config from the env file
     """
 
-    def __init__(self, broker_type: EnvType, config:Config) -> None:
+    def __init__(self, broker_type: EnvType, config:KafkaConfig) -> None:
         self.env_type = broker_type
         self.config = config
 
         if not isinstance(self.env_type, EnvType):
             raise ValueError(f"Invalid env_type: {self.env_type}. Must be an instance of EnvType Enum.")
         
-        if not isinstance(self.config, Config):
+        if not isinstance(self.config, KafkaConfig):
             raise ValueError(f"Invalid config: {self.config}. Must be an instance of Config.")
 
 
@@ -36,9 +34,5 @@ class LoggerFactory:
                 if not isinstance(config, KafkaConfig):
                     raise ValueError("KafkaLogger requires a KafkaConfig instance")
                 return KafkaLogger(config=config)
-            case EnvType.SIMPLE:
-                if not isinstance(config, SimpleConfig):
-                    raise ValueError("SimpleLogger requires a SimpleConfig instance")
-                return SimpleLogger(config=config)
             case _:
                 raise Exception("No matching logger found for the environment type.")
\ No newline at end of file
